@@ -2,10 +2,10 @@ require 'fog/core/collection'
 require 'fog/libvirt/models/compute/interface'
 
 module Fog
-  module Compute
-    class Libvirt
+  module Libvirt
+    class Compute
       class Interfaces < Fog::Collection
-        model Fog::Compute::Libvirt::Interface
+        model Fog::Libvirt::Compute::Interface
 
         def all(filter={})
           load(service.list_interfaces(filter))
