@@ -28,6 +28,9 @@ module Fog
         attribute :boot_order
         attribute :display
         attribute :cpu
+        attribute :hugepages
+        attribute :guest_agent
+        attribute :virtio_rng
 
         attribute :state
 
@@ -75,6 +78,10 @@ module Fog
           action_status
         end
 
+        def update_autostart(value)
+          service.update_autostart(uuid, value)
+        end
+
         def mac
           nics.first.mac if nics && nics.first
         end
@@ -129,9 +136,10 @@ module Fog
         end
 
         #alias methods
-        alias_method :halt,    :poweroff
-        alias_method :stop,    :shutdown
-        alias_method :active?, :active
+        alias_method :halt,       :poweroff
+        alias_method :stop,       :shutdown
+        alias_method :active?,    :active
+        alias_method :autostart?, :autostart
 
         def volumes
           # lazy loading of volumes
@@ -471,13 +479,17 @@ module Fog
             :os_type                => "hvm",
             :arch                   => "x86_64",
             :domain_type            => "kvm",
+            :autostart              => false,
             :iso_dir                => default_iso_dir,
             :network_interface_type => "network",
             :network_nat_network    => "default",
             :network_bridge_name    => "br0",
             :boot_order             => %w[hd cdrom network],
             :display                => default_display,
-            :cpu                    => {}
+            :cpu                    => {},
+            :hugepages              => false,
+            :guest_agent            => true,
+            :virtio_rng             => {},
           }
         end
 
