@@ -4,8 +4,8 @@ require 'ostruct'
 require 'securerandom'
 
 module Fog
-  module Compute
-    module LibvirtUtil
+  module Libvirt
+    module Util
       def xml_element(xml, path, attribute=nil)
         xml = Nokogiri::XML(xml)
         attribute.nil? ? (xml/path).first.text : (xml/path).first[attribute.to_sym]
